@@ -56,6 +56,7 @@ sub configure {
 	$obj->module($module);
 	eval "package $pkg; use $module";
 	croak "$module: $@" if $@;
+	$obj->define('__PACKAGE__' => $module);
 	local *data = "${module}::DATA";
 	if (not eof *data) {
 	    $obj->readrc(*data);
@@ -120,7 +121,7 @@ sub expand {
 	my($name, $re, $string) = @$defent;
 	s/$re/$string/g;
     }
-    s/(\$ENV\{ (['"]?) \w+ \g{-1} \})/$1/xgee;
+    s{ (\$ENV\{ (['"]?) \w+ \g{-1} \}) }{ eval($1) // $1 }xge;
 }
 
 use constant BUILTIN => "__BUILTIN__";
@@ -227,8 +228,25 @@ sub help {
 sub parsetext {
     my $obj = shift;
     my $text = shift;
-    while ($text =~ /(.+)\n?/g) {
-	$obj->parseline($1);
+    my $re = qr{
+	(?|
+	    # HERE document
+	    (.+\s) << (?<mark>\w+) \n
+	    (?<here> (?s:.*?) \n )
+	    \g{mark}\n
+	|
+	    (.+)\n?
+	)
+    }x;
+    while ($text =~ m/$re/g) {
+	my $line = do {
+	    if (defined $+{here}) {
+		$1 . $+{here};
+	    } else {
+		$1;
+	    }
+	};
+	$obj->parseline($line);
     }
     $obj;
 }
@@ -329,14 +347,7 @@ sub run_inits {
     my $obj = shift;
     my $argv = shift;
     my $module = $obj->module;
-
-    ##
-    ## Call function specified with module.
-    ##
-    for my $call ($obj->call) {
-	my $func = $call->can('call') ? $call : parse_func($call);
-	$func->call;
-    }
+    local @ARGV;
 
     ##
     ## Call &initialize if defined.
@@ -346,6 +357,14 @@ sub run_inits {
 	no strict 'refs';
 	&$init($obj, $argv);
     }
+
+    ##
+    ## Call function specified with module.
+    ##
+    for my $call ($obj->call) {
+	my $func = $call->can('call') ? $call : parse_func($call);
+	$func->call;
+    }
 }
 
 1;
@@ -395,10 +414,14 @@ default option.
 
 For the purpose to include following arguments within replaced
 strings, two special notations can be used in option definition.
-String C<$E<lt>nE<gt>> is replaced by the I<n>th argument after the
-substituted option, where I<n> is number start from one.  String
-C<$E<lt>shiftE<gt>> is replaced by following command line argument and
-the argument is removed from option list.
+
+String C<< $<n> >> is replaced by the I<n>th argument after the
+substituted option, where I<n> is number start from one.  Because C<<
+$<0> >> is replaced by the defined option itself, you have to care
+about infinite loop.
+
+String C<< $<shift> >> is replaced by following command line argument
+and the argument is removed from list.
 
 For example, when
 
@@ -412,6 +435,29 @@ will be evaluated as this:
 
     greple --le &line=10,20-30,40
 
+There are three special arguments to manipulate option behavior and
+the rest of arguments.  Argument C<< $<move> >> moves all following
+arguments there, C<< $<remove> >> just removes them, and C<< $<copy>
+>> copies them.  These does not work when included in a part of
+string.
+
+They take optional one or two parameters, those are passed to Perl
+C<splice> function as I<offset> and I<length>.  C<< $<move(0,1)> >> is
+same as C<< $<shift> >>; C<< $<copy(0,1)> >> is same as C<< $<1> >>;
+C<< $<move> >> is same as C<< $<move(0)> >>; C<< $<move(-1)> >> moves
+the last argument; C<< $move(1,1) >> moves second argument.  Next
+example exchange following two arguments.
+
+    option --exch $<move(1,1)>
+
+Because C<< $<move(0,0)> >> does nothing, you can use it to ignore
+option.
+
+    option --deprecated $<move(0,0)>
+
+Note that these handling does not work for B<default> option.  This is
+an implementation issue, and may change in the future.
+
 =item B<expand> I<name> I<string>
 
 Define local option I<name>.  Command B<expand> is almost same as
@@ -438,6 +484,16 @@ use in command line,
     option --kanalist --nocolor -o --join --re '(#kana)+(\n(#kana)+)*'
     help   --kanalist List up Katakana string
 
+Here-document can be used to define string inluding newlines.
+
+    define __script__ <<EOS
+    {
+    	...
+    }  
+    EOS
+
+Special macro C<__PACKAGE__> is pre-defined to module name.
+
 =item B<help> I<name>
 
 Define help message for option I<name>.
@@ -471,7 +527,7 @@ loaded before processing I<--dig> option.
 
 =over 4
 
-=item B<new>
+=item B<new> I<configure option>
 
 Create object.  Parameters are just passed to C<configure> method.
 
